@@ -39,9 +39,25 @@ class GGZCorePlayer
 			normal = GGZ_PLAYER_NORMAL,
 			guest = GGZ_PLAYER_GUEST,
 			admin = GGZ_PLAYER_ADMIN,
+			host = GGZ_PLAYER_HOST,
 			bot = GGZ_PLAYER_BOT
 		};
 
+		/**
+		 * Available permissions */
+		enum PlayerPermission
+		{
+			jointable = GGZ_PERM_JOIN_TABLE,
+			launchtable = GGZ_PERM_LAUNCH_TABLE,
+			roomslogin = GGZ_PERM_ROOMS_LOGIN,
+			roomsadmin = GGZ_PERM_ROOMS_ADMIN,
+			chatannounce = GGZ_PERM_CHAT_ANNOUNCE,
+			chatbot = GGZ_PERM_CHAT_BOT,
+			nostats = GGZ_PERM_NO_STATS,
+			edittables = GGZ_PERM_EDIT_TABLES,
+			tablemessage = GGZ_PERM_TABLE_PRIVMSG
+		};
+
 		/**
 		 * Return the name of this player. */
 		char* name();
@@ -58,17 +74,27 @@ class GGZCorePlayer
 
 		/**
 		 * Player statistics */
+		bool hasRecord();
+		bool hasRating();
+		bool hasRanking();
+		bool hasHighscore();
+
+		/**
+		 * More player statistics */
 		int recordWins();
 		int recordLosses();
 		int recordTies();
 		int recordForfeits();
-
-		/**
-		 * More player statistics */
 		int rating();
 		int ranking();
 		int highscore();
 
+		/**
+		 * Permissions */
+		bool hasPermission(PlayerPermission permission);
+		bool grantPermission(PlayerPermission permission);
+		bool revokePermission(PlayerPermission permission);
+
 	private:
 		GGZPlayer *m_player;
 };
