@@ -37,6 +37,12 @@
 // KGGZ includes
 #include "KGGZInput.h"
 #include "KGGZMeta.h"
+#include "KGGZCommon.h"
+
+// KDE includes
+//#ifndef WITH_HOWL
+#include <dnssd/remoteservice.h>
+//#endif
 
 // Qt includes
 #include <qwidget.h>
@@ -64,7 +70,7 @@ class KGGZConnect : public QWidget
 		// secure connection?
 		int optionSecure();
 
-	protected:
+	//protected:
 		// Widget is about to be shown
 		void showEvent(QShowEvent *e);
 
@@ -95,6 +101,14 @@ class KGGZConnect : public QWidget
 		void slotWrite();
 		// Read from meta server
 		void slotRead();
+//#ifndef WITH_HOWL
+		// Data from the DNSSD implementation
+		void slotService(DNSSD::RemoteService::Ptr ptr);
+		// Data from DNSSD finished
+		void slotServiceFinished();
+//#endif
+		// Metaserver errors
+		void slotError(int code);
 
 	signals:
 		// Emitted if connection is wanted
