@@ -12,10 +12,10 @@ class GGZMetaProtocol : public QObject, public KIO::SlaveBase
 	public:
 		GGZMetaProtocol(const QCString& pool, const QCString& app);
 		~GGZMetaProtocol();
-		virtual void get(const KURL& url);
-		virtual void listDir(const KURL& url);
-		virtual void stat(const KURL& url);
-		virtual void mimetype(const KURL& url);
+		void get(const KURL& url);
+		void listDir(const KURL& url);
+		void stat(const KURL& url);
+		//virtual void mimetype(const KURL& url);
 
 		void work(QString queryclass, QString query);
 		void delegate(QString queryclass, QString url);
@@ -30,6 +30,7 @@ class GGZMetaProtocol : public QObject, public KIO::SlaveBase
 		void jobOperator(const KURL& url);
 		void init(const KURL& url);
 		void debug(QString s);
+		void about();
 
 		KIO::UDSEntry entry;
 		QString m_class, m_query, m_temp;
